%define _requires_exceptions GLIBC_PRIVATE

#one of valgrind internal library is not linked to libc. Not sure if it should be fixed or not (since all test don't pass anyway), so disable check for now
%define _disable_ld_no_undefined 1

# disable debug package, it can prevent valgrind for working properly
%define debug_package   %{nil}

Name: 		valgrind
Version:	3.3.1
Release:	%mkrel 2
Summary: 	Memory debugger
License: 	GPLv2+
Group: 		Development/Other
Source0:	http://www.valgrind.org/downloads/%{name}-%{version}.tar.bz2
# (fc) 3.3.0-4mdv add cachegrind improvement (Fedora)
Patch0:		valgrind-3.3.0-cachegrind-improvements.patch
# (fc) 3.3.0-4mdv fix pkg-config file (RH bug #213149) (Fedora)
Patch1:		valgrind-3.3.0-pkg-config.patch
# (fc) 3.3.0-4mdv fix openat handling (RH bug #208097) (Fedora)
Patch2:		valgrind-3.3.0-openat.patch
# (fc) 3.3.0-4mdv suppress pthread_barrier_wait in helgrind (Fedora)
Patch3:		valgrind-3.3.0-helgrind-p_b_w.patch
# (fc) 3.3.0-4mdv fix malloc_free_fill test with glibc >= 2.7 (SVN, bug #162819)
Patch8:		valgrind-3.3.0-fixtest.patch


URL: 		http://valgrind.org/
ExclusiveArch:	%{ix86} x86_64 ppc
BuildRequires:	glibc-static-devel
BuildRequires:	gdb
Suggests:	gdb
Obsoletes:	valgrind-plugins
BuildRoot: 	%{_tmppath}/%{name}-%{version}

%description
When a program is run under Valgrind's supervision, all reads and
writes of memory are checked, and calls to malloc/new/free/delete are
intercepted. As a result, Valgrind can detect problems such as:

    * Use of uninitialised memory
    * Reading/writing memory after it has been free'd
    * Reading/writing off the end of malloc'd blocks
    * Reading/writing inappropriate areas on the stack
    * Memory leaks -- where pointers to malloc'd blocks are lost forever
    * Passing of uninitialised and/or unaddressible memory to system calls
    * Mismatched use of malloc/new/new [] vs free/delete/delete []


%prep
%setup -q 
%patch0 -p1 -b .cachegrind-improvements
%patch1 -p1 -b .pkg-config
%patch2 -p1 -b .openat
%patch3 -p1 -b .helgrind-p_b_w
%patch8 -p1 -b .fixtest

#needed by patch8
chmod +x memcheck/tests/filter_malloc_free_fill

%build
%configure2_5x

# Force a specific set of default suppressions
echo -n > default.supp
for file in xfree-4.supp glibc-2.34567-NPTL-helgrind.supp glibc-2.8.supp; do
    cat $file >> default.supp
done

perl -p -i -e 's@/usr/X11[^/]+@/usr@g' default.supp

%make

%install
rm -rf %{buildroot}
# Don't strip (prevent valgrind from working properly, as explained in README_PACKAGERS)
export DONT_STRIP=1
%makeinstall

%check
# Ensure there are no unexpected file descriptors open,
# the testsuite otherwise fails.
cat > close_fds.c <<EOF
#include <stdlib.h>
#include <unistd.h>
int main (int argc, char *const argv[])
{
  int i, j = sysconf (_SC_OPEN_MAX);
  if (j < 0)
    exit (1);
  for (i = 3; i < j; ++i)
    close (i);
  execvp (argv[1], argv + 1);
  exit (1);
}
EOF
gcc $RPM_OPT_FLAGS -o close_fds close_fds.c

for i in `find . -type f \( -name *-amd64-linux -o -name *-x86-linux -o -name *-ppc*-linux \)`; do
  case "`file $i`" in
    *ELF*executable*statically\ linked*)
      objcopy -R .debug_loc -R .debug_frame -R .debug_ranges $i
  esac
done

make check || :
# some tests are known to fail,
# just check no more tests are failing than Fedora ;)
echo ===============TESTING===================
./close_fds make regtest || :
echo ===============END TESTING===============



%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc README* ACKNOWLEDGEMENTS
%{_bindir}/*
%{_libdir}/%{name}
%{_includedir}/valgrind/
%{_libdir}/pkgconfig/%{name}.pc
%{_mandir}/man1/%{name}.1*



%changelog
* Mon Jun 30 2008 Frederic Crozat <fcrozat@mandriva.com> 3.3.1-2mdv2009.0
+ Revision: 230240
- Update patch8 with upstream fix

* Thu Jun 26 2008 Frederic Crozat <fcrozat@mandriva.com> 3.3.1-1mdv2009.0
+ Revision: 229225
- Release 3.3.1
- Remove patches 4, 5, 6, 7 (merged upstream)
- Don't regenerate debug package, all debug info should stay in valgrind binaries

* Fri May 30 2008 Paulo Andrade <pcpa@mandriva.com.br> 3.3.0-5mdv2009.0
+ Revision: 213483
- Don't supress warnings only if the binary has been explicitly linked
  with libraries at /usr/X11*/lib*.

  + Frederic Crozat <fcrozat@mandriva.com>
    - Rebuild with glibc 4.3 / glibc 2.8
    - run make test in check section
    - Patch0 (Fedora): add cachegrind improvement
    - Patch1 (Fedora): fix pkgconfig file (RH bug #213149)
    - Patch2 (Fedora): fix openat handling (RH bug #208097)
    - Patch3 (Fedora): suppress pthread_barrier_wait in helgrind
    - Patch4 (Fedora): add suppression for glibc 2.7
    - Patch5 (Fedora): add support for glibc 2.8
    - Patches6, 7 (Fedora): add more syscalls
    - Patch8: fix malloc_free_fill test when glibc >= 2.7

* Thu Feb 21 2008 Adam Williamson <awilliamson@mandriva.com> 3.3.0-3mdv2008.1
+ Revision: 173469
- suggests gdb (#37755)

* Thu Feb 14 2008 Adam Williamson <awilliamson@mandriva.com> 3.3.0-2mdv2008.1
+ Revision: 167680
- new license policy
- drop bogus doc install hacks
- buildrequires gdb (#37739)
- spec clean
- drop Source1 (it's not actually used)

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Tue Dec 18 2007 trem <trem@mandriva.org> 3.3.0-1mdv2008.1
+ Revision: 131903
- update to 3.3.0
- remove patch for glibc-2.6

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

* Mon Aug 06 2007 Olivier Blin <oblin@mandriva.com> 3.2.3-2mdv2008.0
+ Revision: 59231
- use generic man page extension in files list (for lzma)
- add glibc-2.6 support (patch from Gentoo)


* Fri Mar 16 2007 Laurent Montel <lmontel@mandriva.com> 3.2.3-1mdv2007.1
+ Revision: 144737
- 3.2.3

* Sat Jan 13 2007 Michael Scherer <misc@mandriva.org> 3.2.1-1mdv2007.1
+ Revision: 108323
- update to 3.2.1, fix illegal instruction on current libstdc++ on x86_64
- Import valgrind

* Sat Jun 17 2006 Guillaume Rousse <guillomovitch@mandriva.org> 3.2.0-2mdv2007.0
- obsoletes valgrind-plugins

* Wed Jun 14 2006 Guillaume Rousse <guillomovitch@mandriva.org> 3.2.0-1mdv2007.0
- new version
- rpmbuildupdate aware
- spec cleanup
- move doc file in doc directory

* Sat Apr 29 2006 Jerome Soyer <saispo@mandriva.org> 3.1.1-1mdk
- New release 3.1.1

* Fri Feb 17 2006 Christiaan Welvaart <cjw@daneel.dyndns.org> 3.1.0-2mdk
- enable build for ppc

* Thu Dec 01 2005 Laurent MONTEL <lmontel@mandriva.com> 3.1.0-1mdk
- 3.1.0

* Tue Sep 06 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 3.0.1-1mdk
- 3.0.1

* Fri Aug 05 2005 Laurent MONTEL <lmontel@mandriva.com> 3.0.0-1mdk
- 3.0.0

* Thu Mar 24 2005 Laurent MONTEL <lmontel@mandrakesoft.com> 2.4.0-1mdk
- 2.4.0

* Wed Jan 19 2005 Laurent MONTEL <lmontel@mandrakesoft.com> 2.2.0-2mdk
- Remove calltree from this package create new package valgrind-plugins and put callgrind into (because we can't compile callgrind without valgrind)

* Sat Sep 04 2004 Laurent MONTEL <lmontel@mandrakesoft.com> 2.2.0-1mdk
- 2.2.0

* Thu Jul 22 2004 Laurent MONTEL <lmontel@mandrakesoft.com> 2.1.2-1mdk
- 2.1.2 (see http://developer.kde.org/~sewardj/docs-2.0.0/NEWS.txt)

* Fri Apr 23 2004 Laurent MONTEL <lmontel@mandrakesoft.com> 2.1.1-3mdk
- Add calltree plugins for kcachegrind (kdesdk)

* Tue Apr 20 2004 Per yvind Karlsen <peroyvind@linux-mandrake.com> 2.1.1-2mdk
- fix buildrequires
- use %%configure macro
- update url
- drop patches that wasn't applied

* Wed Mar 31 2004 Laurent MONTEL <lmontel@mandrakesoft.com> 2.1.1-1mdk
- new version

* Wed Mar 31 2004 Laurent MONTEL <lmontel@mandrakesoft.com> 2.1.0-3mdk
- Don't package twice manual.html bug #9314

